__author__ = 'David Avsajanishvili'
__copyright__ = 'Copyright (c) Social TRM Ltd.'
__license__ = 'BSD'
__all__ = ['OpenFormResponse', 'CloseFormResponse', 'handler']

from popup_forms.responses import CloseFormResponse, OpenFormResponse
from popup_forms.decorators import handler
